==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/EventGridDataConnection.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin

import com.pulumi.azurenative.synapse.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.synapse.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [EventGridDataConnection].
 */
@PulumiTagMarker
public class EventGridDataConnectionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: EventGridDataConnectionArgs = EventGridDataConnectionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend EventGridDataConnectionArgsBuilder.() -> Unit) {
        val builder = EventGridDataConnectionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): EventGridDataConnection {
        val builtJavaResource =
            com.pulumi.azurenative.synapse.EventGridDataConnection(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return EventGridDataConnection(builtJavaResource)
    }
}

/**
 * Class representing an Event Grid data connection.
 * Azure REST API version: 2021-06-01-preview.
 * ## Example Usage
 * ### KustoPoolDataConnectionsCreateOrUpdate.json
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var eventGridDataConnection = new AzureNative.Synapse.EventGridDataConnection("eventGridDataConnection", new()
 *     {
 *         DataConnectionName = "DataConnections8",
 *         DatabaseName = "KustoDatabase8",
 *         KustoPoolName = "kustoclusterrptest4",
 *         ResourceGroupName = "kustorptest",
 *         WorkspaceName = "synapseWorkspaceName",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/synapse/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := synapse.NewEventGridDataConnection(ctx, "eventGridDataConnection", &synapse.EventGridDataConnectionArgs{
 * 			DataConnectionName: pulumi.String("DataConnections8"),
 * 			DatabaseName:       pulumi.String("KustoDatabase8"),
 * 			KustoPoolName:      pulumi.String("kustoclusterrptest4"),
 * 			ResourceGroupName:  pulumi.String("kustorptest"),
 * 			WorkspaceName:      pulumi.String("synapseWorkspaceName"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.synapse.EventGridDataConnection;
 * import com.pulumi.azurenative.synapse.EventGridDataConnectionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var eventGridDataConnection = new EventGridDataConnection("eventGridDataConnection", EventGridDataConnectionArgs.builder()
 *             .dataConnectionName("DataConnections8")
 *             .databaseName("KustoDatabase8")
 *             .kustoPoolName("kustoclusterrptest4")
 *             .resourceGroupName("kustorptest")
 *             .workspaceName("synapseWorkspaceName")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:synapse:EventGridDataConnection KustoClusterRPTest4/KustoDatabase8/DataConnections8 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/databases/{databaseName}/dataConnections/{dataConnectionName}
 * ```
 */
public class EventGridDataConnection internal constructor(
    override val javaResource: com.pulumi.azurenative.synapse.EventGridDataConnection,
) : KotlinCustomResource(javaResource, EventGridDataConnectionMapper) {
    /**
     * The name of blob storage event type to process.
     */
    public val blobStorageEventType: Output<String>?
        get() = javaResource.blobStorageEventType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The event hub consumer group.
     */
    public val consumerGroup: Output<String>
        get() = javaResource.consumerGroup().applyValue({ args0 -> args0 })

    /**
     * The data format of the message. Optionally the data format can be added to each message.
     */
    public val dataFormat: Output<String>?
        get() = javaResource.dataFormat().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The resource ID where the event grid is configured to send events.
     */
    public val eventHubResourceId: Output<String>
        get() = javaResource.eventHubResourceId().applyValue({ args0 -> args0 })

    /**
     * A Boolean value that, if set to true, indicates that ingestion should ignore the first record of every file
     */
    public val ignoreFirstRecord: Output<Boolean>?
        get() = javaResource.ignoreFirstRecord().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Kind of the endpoint for the data connection
     * Expected value is 'EventGrid'.
     */
    public val kind: Output<String>
        get() = javaResource.kind().applyValue({ args0 -> args0 })

    /**
     * Resource location.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The mapping rule to be used to ingest the data. Optionally the mapping information can be added to each message.
     */
    public val mappingRuleName: Output<String>?
        get() = javaResource.mappingRuleName().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioned state of the resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The resource ID of the storage account where the data resides.
     */
    public val storageAccountResourceId: Output<String>
        get() = javaResource.storageAccountResourceId().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The table where the data should be ingested. Optionally the table information can be added to each message.
     */
    public val tableName: Output<String>?
        get() = javaResource.tableName().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object EventGridDataConnectionMapper : ResourceMapper<EventGridDataConnection> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.synapse.EventGridDataConnection::class == javaResource::class

    override fun map(javaResource: Resource): EventGridDataConnection =
        EventGridDataConnection(
            javaResource as
                com.pulumi.azurenative.synapse.EventGridDataConnection,
        )
}

/**
 * @see [EventGridDataConnection].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [EventGridDataConnection].
 */
public suspend fun eventGridDataConnection(
    name: String,
    block: suspend EventGridDataConnectionResourceBuilder.() -> Unit,
): EventGridDataConnection {
    val builder = EventGridDataConnectionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [EventGridDataConnection].
 * @param name The _unique_ name of the resulting resource.
 */
public fun eventGridDataConnection(name: String): EventGridDataConnection {
    val builder = EventGridDataConnectionResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/EventGridDataConnection.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin

import com.pulumi.azurenative.synapse.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.synapse.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [EventGridDataConnection].
 */
@PulumiTagMarker
public class EventGridDataConnectionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: EventGridDataConnectionArgs = EventGridDataConnectionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend EventGridDataConnectionArgsBuilder.() -> Unit) {
        val builder = EventGridDataConnectionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): EventGridDataConnection {
        val builtJavaResource =
            com.pulumi.azurenative.synapse.EventGridDataConnection(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return EventGridDataConnection(builtJavaResource)
    }
}

/**
 * Class representing an Event Grid data connection.
 * Azure REST API version: 2021-06-01-preview.
 * ## Example Usage
 * ### KustoPoolDataConnectionsCreateOrUpdate.json
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var eventGridDataConnection = new AzureNative.Synapse.EventGridDataConnection("eventGridDataConnection", new()
 *     {
 *         DataConnectionName = "DataConnections8",
 *         DatabaseName = "KustoDatabase8",
 *         KustoPoolName = "kustoclusterrptest4",
 *         ResourceGroupName = "kustorptest",
 *         WorkspaceName = "synapseWorkspaceName",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/synapse/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := synapse.NewEventGridDataConnection(ctx, "eventGridDataConnection", &synapse.EventGridDataConnectionArgs{
 * 			DataConnectionName: pulumi.String("DataConnections8"),
 * 			DatabaseName:       pulumi.String("KustoDatabase8"),
 * 			KustoPoolName:      pulumi.String("kustoclusterrptest4"),
 * 			ResourceGroupName:  pulumi.String("kustorptest"),
 * 			WorkspaceName:      pulumi.String("synapseWorkspaceName"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.synapse.EventGridDataConnection;
 * import com.pulumi.azurenative.synapse.EventGridDataConnectionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var eventGridDataConnection = new EventGridDataConnection("eventGridDataConnection", EventGridDataConnectionArgs.builder()
 *             .dataConnectionName("DataConnections8")
 *             .databaseName("KustoDatabase8")
 *             .kustoPoolName("kustoclusterrptest4")
 *             .resourceGroupName("kustorptest")
 *             .workspaceName("synapseWorkspaceName")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:synapse:EventGridDataConnection KustoClusterRPTest4/KustoDatabase8/DataConnections8 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/databases/{databaseName}/dataConnections/{dataConnectionName}
 * ```
 */
public class EventGridDataConnection internal constructor(
    override val javaResource: com.pulumi.azurenative.synapse.EventGridDataConnection,
) : KotlinCustomResource(javaResource, EventGridDataConnectionMapper) {
    /**
     * The name of blob storage event type to process.
     */
    public val blobStorageEventType: Output<String>?
        get() = javaResource.blobStorageEventType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The event hub consumer group.
     */
    public val consumerGroup: Output<String>
        get() = javaResource.consumerGroup().applyValue({ args0 -> args0 })

    /**
     * The data format of the message. Optionally the data format can be added to each message.
     */
    public val dataFormat: Output<String>?
        get() = javaResource.dataFormat().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The resource ID where the event grid is configured to send events.
     */
    public val eventHubResourceId: Output<String>
        get() = javaResource.eventHubResourceId().applyValue({ args0 -> args0 })

    /**
     * A Boolean value that, if set to true, indicates that ingestion should ignore the first record of every file
     */
    public val ignoreFirstRecord: Output<Boolean>?
        get() = javaResource.ignoreFirstRecord().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Kind of the endpoint for the data connection
     * Expected value is 'EventGrid'.
     */
    public val kind: Output<String>
        get() = javaResource.kind().applyValue({ args0 -> args0 })

    /**
     * Resource location.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The mapping rule to be used to ingest the data. Optionally the mapping information can be added to each message.
     */
    public val mappingRuleName: Output<String>?
        get() = javaResource.mappingRuleName().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioned state of the resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The resource ID of the storage account where the data resides.
     */
    public val storageAccountResourceId: Output<String>
        get() = javaResource.storageAccountResourceId().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The table where the data should be ingested. Optionally the table information can be added to each message.
     */
    public val tableName: Output<String>?
        get() = javaResource.tableName().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object EventGridDataConnectionMapper : ResourceMapper<EventGridDataConnection> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.synapse.EventGridDataConnection::class == javaResource::class

    override fun map(javaResource: Resource): EventGridDataConnection =
        EventGridDataConnection(
            javaResource as
                com.pulumi.azurenative.synapse.EventGridDataConnection,
        )
}

/**
 * @see [EventGridDataConnection].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [EventGridDataConnection].
 */
public suspend fun eventGridDataConnection(
    name: String,
    block: suspend EventGridDataConnectionResourceBuilder.() -> Unit,
): EventGridDataConnection {
    val builder = EventGridDataConnectionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [EventGridDataConnection].
 * @param name The _unique_ name of the resulting resource.
 */
public fun eventGridDataConnection(name: String): EventGridDataConnection {
    val builder = EventGridDataConnectionResourceBuilder()
    builder.name(name)
    return builder.build()
}
